<?php

/**
 * Dashboard: Shortcode Builder.
 *
 * @link    https://plugins360.com
 * @since   1.6.5
 *
 * @package All_In_One_Video_Gallery
 */

$fields = aiovg_get_shortcode_fields();

// Videos
$is_video_found = 0;

$args = array(				
    'post_type' => 'aiovg_videos',			
    'post_status' => 'publish',
    'posts_per_page' => 500,
    'orderby' => 'title', 
    'order' => 'ASC', 
    'no_found_rows' => true,
    'update_post_term_cache' => false,
    'update_post_meta_cache' => false
);

$aiovg_query = new WP_Query( $args );

if ( $aiovg_query->have_posts() ) {
    $is_video_found = 1;
}

// Categories
$is_category_found = 0;

$args = array(			
    'parent'     => 0,
    'hide_empty' => false
);

$terms = get_terms( 'aiovg_categories', $args );			

if ( ! empty( $terms ) && ! is_wp_error( $terms ) ) {
    $is_category_found = 1;
}
?>

<!-- Shortcode Selector -->
<div id="aiovg-shortcode-selector">
    <p class="about-description"><?php esc_html_e( 'Select a shortcode type', 'all-in-one-video-gallery' ); ?></p>

    <ul class="aiovg-radio horizontal">
        <?php
        foreach ( $fields as $shortcode => $params ) {
            printf( 
                '<li><label><input type="radio" name="shortcode" value="%s"%s/>%s</label></li>', 
                esc_attr( $shortcode ), 
                checked( $shortcode, 'videos', false ), 
                esc_html( $params['title'] ) 
            );
        }
        ?>
    </ul>    
</div>

<!-- Shortcode Builder -->
<div id="aiovg-shortcode-builder"> 
    <!-- Left Column -->  
    <div class="aiovg-left-col">
        <div class="aiovg-col-content">         
            <?php 
            foreach ( $fields as $shortcode => $params ) :
                $class = '';
                $error = '';

                if ( 'video' == $shortcode ) {
                    $class = ' aiovg-type-default';
                } elseif ( 'videos' == $shortcode ) {
                    $class = ' aiovg-template-classic'; 
                    
                    if ( ! $is_video_found ) {
                        $error = sprintf( 
                            __( 'No videos found. <a href="%s">Add</a> your first video.', 'all-in-one-video-gallery' ),
                            esc_url( admin_url( 'post-new.php?post_type=aiovg_videos' ) )
                        );
                    }  
                } elseif ( 'categories' == $shortcode ) {
                    $class = ' aiovg-template-grid';

                    if ( ! $is_category_found ) {
                        $error = sprintf( 
                            __( 'No categories found. <a href="%s">Add</a> your first category.', 'all-in-one-video-gallery' ),
                            esc_url( admin_url( 'edit-tags.php?taxonomy=aiovg_categories&post_type=aiovg_videos' ) )
                        );
                    }
                }
                ?>
                <div id="aiovg-shortcode-form-<?php echo esc_attr( $shortcode ); ?>" class="aiovg-shortcode-form<?php echo $class; ?>"<?php if ( 'videos' != $shortcode ) echo ' style="display: none;"'; ?>>
                    <?php 
                    if ( ! empty( $error ) ) {
                        printf(
                            '<p class="aiovg-notice aiovg-notice-error">%s</p>',
                            $error
                        );
                    }
      
                    foreach ( $params['sections'] as $name => $section ) :
                        $class = esc_attr( $name ); 
                        if ( 'general' == $name ) {
                            $class .= ' aiovg-active';
                        } 
                        ?>                         
                        <div class="aiovg-shortcode-section aiovg-shortcode-section-<?php echo $class; ?>"> 
                            <div class="aiovg-shortcode-section-header">            
                                <span class="dashicons-before dashicons-plus"></span>
                                <span class="dashicons-before dashicons-minus"></span>
                                <?php echo esc_html( $section['title'] ); ?>
                            </div>  
                                                    
                            <div class="aiovg-shortcode-controls"<?php if ( 'general' != $name ) echo ' style="display: none;"'; ?>>
                                <?php foreach ( $section['fields'] as $field ) : ?>
                                    <div class="aiovg-shortcode-control aiovg-shortcode-control-<?php echo esc_attr( $field['name'] ); ?>">                                                
                                        <?php if ( 'text' == $field['type'] || 'url' == $field['type'] || 'number' == $field['type'] ) : ?>                                        
                                            <label><?php echo esc_html( $field['label'] ); ?></label>
                                            <input type="text" name="<?php echo esc_attr( $field['name'] ); ?>" class="aiovg-shortcode-field widefat" value="<?php echo esc_attr( $field['value'] ); ?>" data-default="<?php echo esc_attr( $field['value'] ); ?>" />
                                        <?php elseif ( 'textarea' == $field['type'] ) : ?>
                                            <label><?php echo esc_html( $field['label'] ); ?></label>
                                            <textarea name="<?php echo esc_attr( $field['name'] ); ?>" class="aiovg-shortcode-field widefat" rows="8" data-default="<?php echo esc_attr( $field['value'] ); ?>"><?php echo esc_textarea( $field['value'] ); ?></textarea>
                                        <?php elseif ( 'select' == $field['type'] || 'radio' == $field['type'] ) : ?>
                                            <label><?php echo esc_html( $field['label'] ); ?></label> 
                                            <select name="<?php echo esc_attr( $field['name'] ); ?>" class="aiovg-shortcode-field widefat" data-default="<?php echo esc_attr( $field['value'] ); ?>">
                                                <?php
                                                foreach ( $field['options'] as $value => $label ) {
                                                    printf( '<option value="%s"%s>%s</option>', esc_attr( $value ), selected( $value, $field['value'], false ), esc_html( $label ) );
                                                }
                                                ?>
                                            </select>                                                                               
                                        <?php elseif ( 'checkbox' == $field['type'] ) : ?>                                        
                                            <label>				
                                                <input type="checkbox" name="<?php echo esc_attr( $field['name'] ); ?>" class="aiovg-shortcode-field" value="1" data-default="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( $field['value'] ); ?> />
                                                <?php echo esc_html( $field['label'] ); ?>
                                            </label>                                            
                                        <?php elseif ( 'color' == $field['type'] ) : ?>                                        
                                            <label><?php echo esc_html( $field['label'] ); ?></label>
                                            <input type="text" name="<?php echo esc_attr( $field['name'] ); ?>" class="aiovg-shortcode-field aiovg-color-picker widefat" value="<?php echo esc_attr( $field['value'] ); ?>" data-default="<?php echo esc_attr( $field['value'] ); ?>" />
                                        <?php elseif ( 'media' == $field['type'] ) : ?>
                                            <label><?php echo esc_html( $field['label'] ); ?></label>
                                            <div class="aiovg-media-uploader">                                                
                                                <input type="text" name="<?php echo esc_attr( $field['name'] ); ?>" class="aiovg-shortcode-field widefat" value="<?php echo esc_attr( $field['value'] ); ?>" data-default="<?php echo esc_attr( $field['value'] ); ?>" />
                                                <div class="aiovg-upload-media hide-if-no-js">
                                                    <a href="javascript:;" id="aiovg-upload-<?php echo esc_attr( $field['name'] ); ?>" class="button button-secondary" data-format="<?php echo esc_attr( $field['name'] ); ?>">
                                                        <?php esc_html_e( 'Upload File', 'all-in-one-video-gallery' ); ?>
                                                    </a>
                                                </div>
                                            </div>                                            
                                        <?php elseif ( 'parent' == $field['type'] ) : ?>
                                            <label><?php echo esc_html( $field['label'] ); ?></label> 
                                            <?php
                                            $args = array(
                                                'show_option_none'  => '-- ' . esc_html__( 'Select Parent', 'all-in-one-video-gallery' ) . ' --',
                                                'option_none_value' => 0,
                                                'taxonomy'          => 'aiovg_categories',
                                                'name' 			    => esc_attr( $field['name'] ),
                                                'class'             => 'aiovg-shortcode-field widefat',
                                                'orderby'           => 'name',
                                                'selected'          => 0,
                                                'hierarchical'      => true,
                                                'depth'             => 10,
                                                'show_count'        => false,
                                                'hide_empty'        => false
                                            );                           
                                            
                                            wp_dropdown_categories( $args );
                                        elseif ( 'categories' == $field['type'] ) : ?>
                                            <label><?php echo esc_html( $field['label'] ); ?></label> 
                                            <ul name="<?php echo esc_attr( $field['name'] ); ?>" class="aiovg-shortcode-field aiovg-checklist widefat" data-default="">
                                                <?php
                                                $args = array(
                                                'taxonomy'      => 'aiovg_categories',
                                                'walker'        => null,
                                                'checked_ontop' => false
                                                ); 
                                            
                                                wp_terms_checklist( 0, $args );
                                                ?>
                                            </ul>
                                        <?php endif; ?>

                                        <!-- Hint -->
                                        <?php if ( ! empty( $field['description'] ) ) : ?>                            
                                            <span class="description"><?php echo wp_kses_post( $field['description'] ); ?></span>                        
                                        <?php endif; ?>
                                    </div>    
                                <?php endforeach; ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endforeach; ?>

            <p>
                <a href="#aiovg-shortcode-modal" id="aiovg-generate-shortcode" class="aiovg-modal-button button-primary">
                    <?php esc_attr_e( 'Generate Shortcode', 'all-in-one-video-gallery' ); ?>
                </a>
            </p>
        </div>
    </div>

    <!-- Right Column -->
    <div class="aiovg-right-col">
        <div class="aiovg-col-content">
            <div id="aiovg-shortcode-instructions-video" class="aiovg-shortcode-instructions" style="display: none;">
                <p class="about-description">
                    <?php esc_html_e( 'How to add a single video in my POST/PAGE?', 'all-in-one-video-gallery' ); ?>
                </p>

                <p>
                    <?php esc_html_e( 'You can use one of the following methods,', 'all-in-one-video-gallery' ); ?>
                </p>

                <p>
                    <span class="dashicons dashicons-arrow-left-alt"></span>  
                    <?php esc_html_e( 'Use the shortcode builder in this page to build your shortcode, then add it in your POST/PAGE.', 'all-in-one-video-gallery' ); ?>
                </p>

                <p>
                    <span>2.</span> 
                    <?php 
                    printf( 
                        __( '<a href="%s">Add</a> your video using our "Custom Post Type" form, copy the shortcode, then add it in your POST/PAGE.', 'all-in-one-video-gallery' ),
                        esc_url( admin_url( 'post-new.php?post_type=aiovg_videos' ) )
                    ); 
                    ?>
                </p>

                <p>
                    <span>3.</span> 
                    <?php 
                    printf( 
                        __( 'Use the <a href="%s">AIOVG - Video Player</a> Gutenberg block and add the video directly in your POST/PAGE.', 'all-in-one-video-gallery' ), 
                        esc_url( admin_url( 'post-new.php?post_type=page' ) ) 
                    ); 
                    ?>
                </p>

                <p>
                    <span>4.</span> 
                    <?php 
                    printf( 
                        __( 'Use the <a href="%s">AIOVG - Video Player</a> widget in your website sidebars.', 'all-in-one-video-gallery' ), 
                        esc_url( admin_url( 'widgets.php' ) ) 
                    ); 
                    ?>
                </p>
            </div>

            <div id="aiovg-shortcode-instructions-videos" class="aiovg-shortcode-instructions">
                <p class="about-description">
                    <?php esc_html_e( 'How to create/add a video gallery?', 'all-in-one-video-gallery' ); ?>
                </p>

                <p>
                    <span>1.</span> 
                    <?php
                    printf(
                        __( 'Optional. <a href="%s">Add Categories</a>', 'all-in-one-video-gallery' ),
                        esc_url( admin_url( 'edit-tags.php?taxonomy=aiovg_categories&post_type=aiovg_videos' ) )
                    );
                    ?>
                </p>

                <p>
                    <span>2.</span>  
                    <?php
                    printf(
                        __( '<a href="%s">Add Videos</a>', 'all-in-one-video-gallery' ),
                        esc_url( admin_url( 'edit.php?post_type=aiovg_videos' ) )
                    );
                    ?>
                </p>

                <p>
                    <span>3.</span> 
                    <?php esc_html_e( 'Then, use one of the following methods to build and show the gallery in your site front-end,', 'all-in-one-video-gallery' ); ?>
                </p>

                <p class="aiovg-indent">
                    <span class="dashicons dashicons-arrow-left-alt"></span>  
                    <?php esc_html_e( 'Use the shortcode builder in this page to build your shortcode, then add it in your POST/PAGE.', 'all-in-one-video-gallery' ); ?>
                </p>

                <p class="aiovg-indent">
                    <span class="dashicons dashicons-arrow-right"></span>   
                    <?php 
                    printf( 
                        __( 'Use the <a href="%s">AIOVG - Video Gallery</a> Gutenberg block in your POST/PAGE.', 'all-in-one-video-gallery' ), 
                        esc_url( admin_url( 'post-new.php?post_type=page' ) ) 
                    ); 
                    ?>
                </p>

                <p class="aiovg-indent">
                    <span class="dashicons dashicons-arrow-right"></span>  
                    <?php 
                    printf( 
                        __( 'Use the <a href="%s">AIOVG - Video Gallery</a> widget in your website sidebars.', 'all-in-one-video-gallery' ), 
                        esc_url( admin_url( 'widgets.php' ) ) 
                    ); 
                    ?>
                </p>
            </div>

            <div id="aiovg-shortcode-instructions-categories" class="aiovg-shortcode-instructions" style="display: none;">
                <p class="about-description">
                    <?php esc_html_e( 'How to add/show video categories?', 'all-in-one-video-gallery' ); ?>
                </p>

                <p>
                    <span>1.</span> 
                    <?php
                    printf(
                        __( '<a href="%s">Add Categories</a>', 'all-in-one-video-gallery' ),
                        esc_url( admin_url( 'edit-tags.php?taxonomy=aiovg_categories&post_type=aiovg_videos' ) )
                    );
                    ?>
                </p>

                <p>
                    <span>2.</span> 
                    <?php esc_html_e( 'Then, use one of the following methods to show the video categories in your site front-end,', 'all-in-one-video-gallery' ); ?>
                </p>

                <p class="aiovg-indent">
                    <span class="dashicons dashicons-arrow-left-alt"></span>  
                    <?php esc_html_e( 'Use the shortcode builder in this page to build your shortcode, then add it in your POST/PAGE.', 'all-in-one-video-gallery' ); ?>
                </p>

                <p class="aiovg-indent">
                    <span class="dashicons dashicons-arrow-right"></span>   
                    <?php 
                    printf( 
                        __( 'Use the <a href="%s">AIOVG - Video Categories</a> Gutenberg block in your POST/PAGE.', 'all-in-one-video-gallery' ), 
                        esc_url( admin_url( 'post-new.php?post_type=page' ) ) 
                    ); 
                    ?>
                </p>

                <p class="aiovg-indent">
                    <span class="dashicons dashicons-arrow-right"></span>  
                    <?php 
                    printf( 
                        __( 'Use the <a href="%s">AIOVG - Video Categories</a> widget in your website sidebars.', 'all-in-one-video-gallery' ), 
                        esc_url( admin_url( 'widgets.php' ) ) 
                    ); 
                    ?>
                </p>
            </div>

            <div id="aiovg-shortcode-instructions-search_form" class="aiovg-shortcode-instructions" style="display: none;">
                <p class="about-description">
                    <?php esc_html_e( 'How to create video search functionality?', 'all-in-one-video-gallery' ); ?>
                </p>

                <p>
                    <?php esc_html_e( 'You can use one of the following methods to add the videos search form in your website,', 'all-in-one-video-gallery' ); ?>
                </p>

                <p>
                    <span class="dashicons dashicons-arrow-left-alt"></span>  
                    <?php esc_html_e( 'Use the shortcode builder in this page to build your shortcode, then add it in your POST/PAGE.', 'all-in-one-video-gallery' ); ?>
                </p>

                <p>
                    <span>2.</span>  
                    <?php 
                    printf( 
                        __( 'Use the <a href="%s">AIOVG - Search Form</a> Gutenberg block in your POST/PAGE.', 'all-in-one-video-gallery' ), 
                        esc_url( admin_url( 'post-new.php?post_type=page' ) ) 
                    ); 
                    ?>
                </p>

                <p>
                    <span>3.</span>  
                    <?php 
                    printf( 
                        __( 'Use the <a href="%s">AIOVG - Search Form</a> widget in your website sidebars.', 'all-in-one-video-gallery' ), 
                        esc_url( admin_url( 'widgets.php' ) ) 
                    ); 
                    ?>
                </p>

                <p>
                    <span class="dashicons dashicons-info"></span> 
                    <?php 
                    printf( 
                        __( 'No matter where you add the search form, but the search results will always be displayed in the <a href="%s">Search Videos</a> page that is added by our plugin dynamically during the activation.', 'all-in-one-video-gallery' ), 
                        esc_url( admin_url( 'admin.php?page=aiovg_settings&tab=advanced&section=aiovg_page_settings' ) ) 
                    ); 
                    ?>
                </p>
            </div>
        </div>
    </div>
</div>

<!-- Shortcode Modal -->
<div id="aiovg-shortcode-modal" class="aiovg-modal mfp-hide">
    <div class="aiovg-modal-body">
        <p><?php esc_html_e( 'Congrats! copy the shortcode below and paste it in your POST/PAGE where you need the gallery,', 'all-in-one-video-gallery' ); ?></p>
        <textarea id="aiovg-shortcode" class="widefat code" autofocus="autofocus" onfocus="this.select()"></textarea>
    </div>
</div>
